@@ -104,8 +104,13 @@ class Parser(object):
     def __init__(self, loader):
         # type: (Any) -> None
         self.loader = loader
-        if self.loader is not None:
+        if self.loader is not None and getattr(self.loader, '_parser', None) is None:
             self.loader._parser = self
+        self.reset_parser()
+
+    def reset_parser(self):
+        # type: () -> None
+        # Reset the state attributes (to clear self-references)
         self.current_event = None
         self.yaml_version = None
         self.tag_handles = {}  # type: Dict[Any, Any]
@@ -113,16 +118,22 @@ class Parser(object):
         self.marks = []   # type: List[Any]
         self.state = self.parse_stream_start  # type: Any
 
+    def dispose(self):
+        self.reset_parser()
+
     @property
     def scanner(self):
         # type: () -> Any
+        if hasattr(self.loader, 'typ'):
+            self.loader.scanner
         return self.loader._scanner
 
-    def dispose(self):
-        # type: () -> None
-        # Reset the state attributes (to clear self-references)
-        self.states = []
-        self.state = None
+    @property
+    def resolver(self):
+        # type: () -> Any
+        if hasattr(self.loader, 'typ'):
+            self.loader.resolver
+        return self.loader._resolver
 
     def check_event(self, *choices):
         # type: (Any) -> bool
@@ -239,7 +250,10 @@ class Parser(object):
         event = DocumentEndEvent(start_mark, end_mark, explicit=explicit)
 
         # Prepare the next state.
-        self.state = self.parse_document_start
+        if self.resolver.processing_version == (1, 1):
+            self.state = self.parse_document_start
+        else:
+            self.state = self.parse_implicit_document_start
 
         return event
 
